@@ -1,13 +1,13 @@
-# Copyrights 2001-2010 by Mark Overmeer.
+# Copyrights 2001-2011 by Mark Overmeer.
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 1.06.
+# Pod stripped from pm file by OODoc 2.00.
 use strict;
 use warnings;
 
 package Mail::Message;
 use vars '$VERSION';
-$VERSION = '2.095';
+$VERSION = '2.099';
 
 use base 'Mail::Reporter';
 
@@ -183,7 +183,7 @@ sub head(;$)
         return undef;
     }
 
-    $self->log(INTERNAL => "wrong type of head for message $self")
+    $self->log(INTERNAL => "wrong type of head ($head) for message $self")
         unless ref $head && $head->isa('Mail::Message::Head');
 
     $head->message($self);
@@ -214,8 +214,8 @@ sub study($)
 
 
 sub from()
-{  my $from = shift->head->get('From') or return ();
-   map {$_->addresses} $from;
+{  my @from = shift->head->get('From') or return ();
+   map {$_->addresses} @from;
 }
 
 
