@@ -1,13 +1,13 @@
-# Copyrights 2001-2010 by Mark Overmeer.
+# Copyrights 2001-2011 by Mark Overmeer.
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 1.06.
+# Pod stripped from pm file by OODoc 2.00.
 use strict;
 use warnings;
 
 package Mail::Message::Field::Full;
 use vars '$VERSION';
-$VERSION = '2.095';
+$VERSION = '2.099';
 
 use base 'Mail::Message::Field';
 
@@ -20,6 +20,7 @@ use Mail::Message::Field::Structured;
 use Mail::Message::Field::Unstructured;
 use Mail::Message::Field::Addresses;
 use Mail::Message::Field::URIs;
+use Mail::Message::Field::Date;
 
 my $atext = q[a-zA-Z0-9!#\$%&'*+\-\/=?^_`{|}~];  # from RFC
 my $atext_ill = q/\[\]/;     # illegal, but still used (esp spam)
@@ -33,19 +34,19 @@ use overload '""' => sub { shift->decodedBody };
 my %implementation;
 
 BEGIN {
-   $implementation{$_} = 'Addresses' foreach
-      qw/from to sender cc bcc reply-to envelope-to
+   $implementation{$_} = 'Addresses'
+      for qw/from to sender cc bcc reply-to envelope-to
          resent-from resent-to resent-cc resent-bcc resent-reply-to
          resent-sender
          x-beenthere errors-to mail-follow-up x-loop delivered-to
          original-sender x-original-sender/;
-   $implementation{$_} = 'URIs' foreach
-      qw/list-help list-post list-subscribe list-unsubscribe list-archive
-         list-owner/;
-   $implementation{$_} = 'Structured' foreach
-      qw/content-disposition content-type/;
-#  $implementation{$_} = 'Date' foreach
-#     qw/date resent-date/;
+   $implementation{$_} = 'URIs'
+      for qw/list-help list-post list-subscribe list-unsubscribe
+         list-archive list-owner/;
+   $implementation{$_} = 'Structured'
+      for qw/content-disposition content-type/;
+   $implementation{$_} = 'Date'
+      for qw/date resent-date/;
 }
 
 sub new($;$$@)
@@ -297,7 +298,9 @@ sub _decoder($$$)
 
 sub decode($@)
 {   my $self    = shift;
-    my @encoded = split /(\=\?[^?]*\?[bqBQ]?\?[^?]*\?\=)/, shift;
+    my @encoded = split /(\=\?[^?\s]*\?[bqBQ]?\?[^?\s]*\?\=)/, shift;
+    @encoded or return '';
+
     my %args    = @_;
 
     my $is_text = defined $args{is_text} ? $args{is_text} : 1;
