@@ -1,14 +1,14 @@
-# Copyrights 2001-2010 by Mark Overmeer.
+# Copyrights 2001-2011 by Mark Overmeer.
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 1.06.
+# Pod stripped from pm file by OODoc 2.00.
 
 use strict;
 use warnings;
 
 package Mail::Transport::POP3;
 use vars '$VERSION';
-$VERSION = '2.095';
+$VERSION = '2.099';
 
 use base 'Mail::Transport::Receive';
 
@@ -25,7 +25,8 @@ sub init($)
 
     $self->SUPER::init($args) or return;
 
-    $self->{MTP_auth}    = $args->{authenticate} || 'AUTO';
+    $self->{MTP_auth} = $args->{authenticate} || 'AUTO';
+    $self->{MTP_ssl}  = $args->{use_ssl};
     return unless $self->socket;   # establish connection
 
     $self;
@@ -52,13 +53,9 @@ sub messages()
     $self->{MTP_messages};
 }
 
-#------------------------------------------
-
 
 sub folderSize() { shift->{MTP_total} }
 
-#------------------------------------------
-
 
 sub header($;$)
 {   my ($self, $uidl) = (shift, shift);
@@ -71,8 +68,6 @@ sub header($;$)
     $self->sendList($socket, "TOP $n $bodylines$CRLF");
 }
 
-#------------------------------------------
-
 
 sub message($;$)
 {   my ($self, $uidl) = @_;
@@ -93,8 +88,6 @@ sub message($;$)
     $message;
 }
 
-#------------------------------------------
-
 
 sub messageSize($)
 {   my ($self, $uidl) = @_;
@@ -116,8 +109,6 @@ sub messageSize($)
     $list->[$n];
 }
 
-#------------------------------------------
-
 
 sub deleted($@)
 {   my $dele = shift->{MTP_dele} ||= {};
@@ -125,16 +116,11 @@ sub deleted($@)
 }
 
 
-#------------------------------------------
-
-
 sub deleteFetched()
 {   my $self = shift;
     $self->deleted(1, keys %{$self->{MTP_fetched}});
 }
 
-#------------------------------------------
-
 
 sub disconnect()
 {   my $self = shift;
@@ -165,8 +151,6 @@ sub disconnect()
     OK($quit);
 }
 
-#------------------------------------------
-
 
 sub fetched(;$)
 {   my $self = shift;
@@ -174,17 +158,12 @@ sub fetched(;$)
     $self->{MTP_fetched};
 }
 
-#------------------------------------------
-
 
 sub id2n($;$) { shift->{MTP_uidl2n}{shift()} }
 
 #------------------------------------------
 
 
-#------------------------------------------
-
-
 sub socket(;$)
 {   my $self = shift;
 
@@ -205,8 +184,6 @@ sub socket(;$)
     $self->{MTP_socket} = $socket;
 }
 
-#------------------------------------------
-
 
 sub send($$)
 {   my $self = shift;
@@ -224,8 +201,6 @@ sub send($$)
     $response;
 }
 
-#------------------------------------------
-
 
 sub sendList($$)
 {   my $self     = shift;
@@ -245,20 +220,14 @@ sub sendList($$)
     \@list;
 }
 
-#------------------------------------------
-
 sub DESTROY()
 {   my $self = shift;
     $self->SUPER::DESTROY;
     $self->disconnect if $self->{MTP_socket}; # only do if not already done
 }
 
-#------------------------------------------
-
 sub OK($;$) { substr(shift || '', 0, 3) eq '+OK' }
 
-#------------------------------------------
-
 sub _connection(;$)
 {   my $self = shift;
 
@@ -275,8 +244,6 @@ sub _connection(;$)
     $socket;
 }
 
-#------------------------------------------
-
 
 sub login(;$)
 {   my $self = shift;
@@ -291,7 +258,10 @@ sub login(;$)
         return;
     }
 
-    my $socket = eval {IO::Socket::INET->new("$host:$port")};
+    my $net    = $self->{MTP_ssl} ? 'IO::Socket::SSL' : 'IO::Socket::INET';
+    eval "require $net" or die $@;
+
+    my $socket = eval {$net->new("$host:$port")};
     unless($socket)
     {   $self->log(ERROR => "Cannot connect to $host:$port for POP3: $!");
         return;
